#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rio
version:              0.1.25.0
visibility:           public
id:                   rio-0.1.25.0-9tFlGoBvXpv5d0KDA2qtut
key:                  rio-0.1.25.0-9tFlGoBvXpv5d0KDA2qtut
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio#readme
synopsis:             A standard library for Haskell
description:
    See README and Haddocks at <https://www.stackage.org/package/rio>

category:             Control
abi:                  a2e223c1335c2f6eb00b6deff20a432d
exposed:              True
exposed-modules:
    RIO RIO.ByteString RIO.ByteString.Lazy RIO.ByteString.Lazy.Partial
    RIO.ByteString.Partial RIO.Char RIO.Char.Partial RIO.Deque
    RIO.Directory RIO.File RIO.FilePath RIO.HashMap RIO.HashMap.Partial
    RIO.HashSet RIO.Lens RIO.List RIO.List.Partial RIO.Map
    RIO.Map.Partial RIO.Map.Unchecked RIO.NonEmpty RIO.NonEmpty.Partial
    RIO.Partial RIO.Prelude RIO.Prelude.Simple RIO.Prelude.Types
    RIO.Process RIO.Seq RIO.Set RIO.Set.Partial RIO.Set.Unchecked
    RIO.State RIO.Text RIO.Text.Lazy RIO.Text.Lazy.Partial
    RIO.Text.Partial RIO.Time RIO.Vector RIO.Vector.Boxed
    RIO.Vector.Boxed.Partial RIO.Vector.Boxed.Unsafe RIO.Vector.Partial
    RIO.Vector.Storable RIO.Vector.Storable.Partial
    RIO.Vector.Storable.Unsafe RIO.Vector.Unboxed
    RIO.Vector.Unboxed.Partial RIO.Vector.Unboxed.Unsafe
    RIO.Vector.Unsafe RIO.Writer

hidden-modules:
    RIO.Prelude.Display RIO.Prelude.Exit RIO.Prelude.Extra
    RIO.Prelude.IO RIO.Prelude.Lens RIO.Prelude.Logger
    RIO.Prelude.Reexports RIO.Prelude.Renames RIO.Prelude.RIO
    RIO.Prelude.Text RIO.Prelude.Trace RIO.Prelude.URef

import-dirs:          /usr/lib/ghc-9.6.6/site-local/rio-0.1.25.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rio-0.1.25.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rio-0.1.25.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio
hs-libraries:         HSrio-0.1.25.0-9tFlGoBvXpv5d0KDA2qtut
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    hashable-1.4.7.0-IundBnRd4VH238tCbJShYq
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS mtl-2.3.1
    primitive-0.9.1.0-7BU3lI8ZSpRANXT28DiNLA process-1.6.19.0
    text-2.0.2 time-1.12.2
    typed-process-0.2.13.0-Dfig2CH9X0Q5cI9bXZXAQ9 unix-2.8.4.0
    unliftio-0.2.25.1-DscakO0OUYTI6rllvWargg
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-6KS41JVoQWZ5mM86HX5ZiJ
    vector-0.13.2.0-CGL8pnIxGMbHvZ63ZDtObP

haddock-interfaces:   /usr/share/doc/haskell-rio/html/rio.haddock
haddock-html:         /usr/share/doc/haskell-rio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

